function [X,nit] = newton(f,x0,prec,maxit)
% [X,nit] = newton(f,x0,prec,maxit)
%   Reseni rovnice f(x)=0 pomoci Newtonovy metody
%   - nehotova verze  programu k dodelani.
%
% Vstup:
%     f - anonymni funkce
%    x0 - pocatecni iterace
%  prec - presnost, implicitni hodnota je 10^-6
% maxit - maximalni pocet iteraci, implicitni hodnota je 50
%
% Vystup:
%     X - priblizne reseni
%   nit - pocet pouzitych iteraci
% 
% Priklad - vypocet treti odmocniny z 5:
%   f=@(x)x.^3-5;[x,n]=newton(f,2);

if nargin < 2
    error('Malo vstupnich promennych!');
end

% presnost
if (nargin < 3)
    prec = 0.000001;
end

% maximalni pocet iteraci
if (nargin < 4)
    maxit = 50;
end

df=matlabFunction(diff(sym(f))); % derivace

x1 = x0-f(x0)/df(x0);           % prvni iterace
nit=1;                          % pocet iteraci

while % hlavni cyklus, zde je potreba program dodelat

end     % konce cyklu while


end		% konec funkce

